@@ -2,12 +2,12 @@ package Weed::FieldSet;
 
 use Weed 'X3DFieldSet : X3DArrayHash ()';
 
-our $VERSION = '0.002';
+our $VERSION = '0.007';
 
 use Weed::Tie::Field;
 
 sub new {
-	my ( $self, $fieldDefinitions, $parent ) = @_;
+	my ( $self, $fieldDefinitions, $node ) = @_;
 
 	my @fields;
 	my %fields;
@@ -16,31 +16,23 @@ sub new {
 	for ( my $i = 0 ; $i < @$fieldDefinitions ; $i++ ) {
 		my $fieldDefinition = $fieldDefinitions->[$i];
 		my $name            = $fieldDefinition->getName;
-		my $field           = $fieldDefinition->createField($parent);
+		my $field           = $fieldDefinition->createField($node);
 
 		$fields[$i] = $field;
 		$fields{$name} = $field;
 
+		# make this a real tied hash later, maybe
 		tie $tiedFields{$name}, 'Weed::Tie::Field', $field;
-		scalar $tiedFields{$name};    # make perl know that this is a ref
+		# ticket 44217; make perl know that this is a ref
+		scalar $tiedFields{$name};    #
 	}
 
 	my $this = $self->X3DArrayHash::new( \@fields, \%fields );
-	$$this->{tiedFields} = new X3DHash \%tiedFields;
+	$$this->{tiedFields} = \%tiedFields;
 
 	return $this;
 }
 
-# sub getClone {
-# 	my $this = shift;
-# 	my $copy = $this->new( $this->getName );
-#
-# 	$$copy->{fields}->{$_}->setValue( $this->getField($_) )
-# 	  foreach map { $_->getName } $this->getFieldDefinitions;
-#
-# 	return $copy;
-# }
-
 sub getField : lvalue {
 	my ( $this, $name ) = @_;
 
@@ -91,7 +83,7 @@ sub toString {
 			$string .= X3DGenerator->indent;
 			$string .= $_->getName;
 			$string .= X3DGenerator->space;
-			$string .= $_->isa('SFString') ? sprintf X3DGenerator->STRING, $_ : $_;
+			$string .= $_;
 			$string .= X3DGenerator->tidy_break;
 		}
 		X3DGenerator->dec;
