@@ -1,17 +1,16 @@
 package Weed::FieldTypes::SFDouble;
 
-our $VERSION = '0.009';
+our $VERSION = '0.01';
 
 use Weed 'SFDouble : X3DField { 0 }';
 
 use base 'Weed::BaseFieldTypes::Scalar';
 
-use Weed::Parse::Double;
-
 sub setValue {
 	my ( $this, $value ) = @_;
+
 	$this->X3DField::setValue(
-		defined $value ? Weed::Parse::Double::double( \"$value" ) || 0 : $this->getDefaultValue
+		defined $value ? eval { no warnings; $value + 0 } || 0 : $this->getDefaultValue
 	);
 }
 
