@@ -1,7 +1,7 @@
 package Weed::Package;
 use Weed::Perl;
 
-our $VERSION = '0.01';
+our $VERSION = '0.014';
 
 #use Package::Generator;
 #Symbol::delete_package wipes out a whole package namespace. Note this routine is not exported by default--you may want to import it explicitly.
@@ -16,6 +16,9 @@ use Weed::Parse::Concept;
 our $_space     = qr/\s+/so;
 our $_type_name = qr/^([\$\@%&*]?)(.*)/so;
 
+our $Namespace = "";
+our $Types     = [];
+
 sub import {
 	my $to = shift;
 
@@ -43,26 +46,32 @@ sub exists { UNIVERSAL::can( $_[0], 'can' ) ? YES : NO }
 sub createType {
 	my ( $package, $base, $declaration, @imports ) = @_;
 
-	#printf "X3DUniversal createType %s %s\n", $package, $base;
-
 	my $description = Weed::Parse::Concept::parse($declaration);
 	if ( ref $description ) {
 
 		my $typeName = $description->{typeName};
 
-		X3DPackage::setBase( $typeName, $package, @imports );
-		X3DPackage::setSupertypes( $typeName,
+		my $packageName = $Namespace ? "$Namespace\::$typeName" : $typeName;
+		return if X3DPackage::exists($packageName);
+		#printf "X3DUniversal createType %s %s %s %s\n", $package, $base, $typeName, $packageName;
+
+		X3DPackage::setBase( $packageName, $package, @imports );
+		X3DPackage::setSupertypes( $packageName,
 			@{ $description->{supertypes} } ?
 			  @{ $description->{supertypes} } :
 			  $base
 		);
-		X3DPackage::setBase( $typeName, $description->{base} );
 
 		#printf "X3DUniversal createType %s : %s %s\n", $typeName, $package, $base;
-		X3DPackage::Scalar( $typeName, "Description" ) = $description;
+		X3DPackage::Scalar( $packageName, "Description" ) = $description;
 
-		$typeName->SET_DESCRIPTION($description)
-		  if $typeName->can('SET_DESCRIPTION');
+		#printf "X3DUniversal createType %s\n", $packageName;
+
+		if ( defined $Types ) {
+			push @$Types, $packageName;
+		} else {
+			$packageName->X3DPackage::initializeType;
+		}
 
 	} else {
 		Carp::croak "Error Parse::Concept: '$declaration'\n", $@ if $@;
@@ -71,8 +80,25 @@ sub createType {
 	return;
 }
 
+sub initializeTypes {
+	$_->X3DPackage::initializeType foreach @$Types;
+	$Types = undef;
+}
+
+sub initializeType {
+	my ($package) = @_;
+	#printf "X3DUniversal initializeType %s %s\n", $package, X3DPackage::Scalar( $package, "Description" );
+
+	$package->SET_DESCRIPTION( X3DPackage::Scalar( $package, "Description" ) )
+	  if $package->can('SET_DESCRIPTION');
+
+}
+
 sub getName { ref( $_[0] ) || $_[0] }
 
+sub getNamespace { $Namespace }
+sub setNamespace { $Namespace = $_[1] || '' }
+
 #sub getPath { [ Class::ISA::self_and_super_path( X3DPackage::getName( $_[0] ) ) ] }
 sub getPath {
 	my $package = $_[0];
@@ -157,18 +183,6 @@ sub setBase {
 	return YES;
 }
 
-# sub constants {
-# 	my $package   = X3DPackage::getName(shift);
-# 	my %constants = @_;
-# 	no strict 'refs';
-# 	while ( my ( $name, $value ) = each %constants ) {
-# 		my $full_name = "${package}::$name";
-# 		*$full_name = sub () { $value };
-# 	}
-# }
-
-#*alias = \&base;
-
 sub expression {
 	my $alias    = shift;
 	my $original = shift;
@@ -210,7 +224,7 @@ sub _import {
 		$expression .= X3DPackage::statements( $original, @_ );
 	}
 
-	printf "%s\n", $expression;
+	#printf "%s\n", $expression;
 	eval $expression;
 
 	if ($@) {
@@ -304,6 +318,13 @@ sub Hash : lvalue {
 	%$property;
 }
 
+sub Glob : lvalue {
+	my ( $this, $name ) = @_;
+	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
+	no strict 'refs';
+	*$property;
+}
+
 sub getSubroutine {
 	my ( $this, $name ) = @_;
 	my $property = sprintf "%s::X3DSubroutine::%s", $this->X3DPackage::getName, $name;
@@ -311,17 +332,18 @@ sub getSubroutine {
 	no strict 'refs';
 	unless ( defined $$property ) {
 		$$property = [];
-		push @$$property, map { \&{"${_}::${name}"} }
+		push @$$property, reverse map { \&{"${_}::${name}"} }
 		  grep { exists &{"${_}::${name}"} } @{ X3DPackage::getPath($this) };
 	}
 
 	return $$property;
 }
 
-#sub call {
-#	my ( $this, $name ) = ( shift, shift );
-#	return map { &$_( $this, @_ ) } X3DPackage::can( $this, $name );
-#}
+sub Call {
+	my ( $this, $name ) = ( shift, shift );
+	$_->( $this, @_ ) foreach @{ $this->X3DPackage::getSubroutine($name) };
+	return;
+}
 
 #sub reverse_call {
 #	my ( $this, $name ) = ( shift, shift );
