@@ -1,17 +1,11 @@
 package Weed::Symbols;
 use Weed::Perl;
 
-our $VERSION = '0.009';
+our $VERSION = '0.01';
 
 use base 'Exporter';
 
 our @EXPORT = qw(
-  $_open_parenthesis_
-  $_close_parenthesis_
-  $_swung_dash_
-  $_in_
-  $_out_
-
   $_tab_
   $_space_
   $_break_
@@ -54,16 +48,13 @@ our @EXPORT = qw(
   $_eventOut_
   $_exposedField_
   $_field_
-);
+  
+  $_open_parenthesis_
+  $_close_parenthesis_
+  $_in_
+  $_out_
 
-# Concept
-our $_open_parenthesis_    = '(';
-our $_close_parenthesis_   = ')';
-our $_open_angle_bracket_  = '<';
-our $_close_angle_bracket_ = '>';
-our $_swung_dash_          = '~';
-our $_in_                  = 'in';
-our $_out_                 = 'out';
+);
 
 # General
 our $_tab_   = ' ';
@@ -113,5 +104,14 @@ our $_eventOut_     = 'eventOut';
 our $_exposedField_ = 'exposedField';
 our $_field_        = 'field';
 
+# Concept
+our $_open_parenthesis_    = '(';
+our $_close_parenthesis_   = ')';
+#our $_open_angle_bracket_  = '<';
+#our $_close_angle_bracket_ = '>';
+#our $_swung_dash_          = '~';
+our $_in_                  = 'in';
+our $_out_                 = 'out';
+
 1;
 __END__
