@@ -1,6 +1,18 @@
 package X3D;
+
+use base 'Weed';
+
+use 5.008008;
+
+our $VERSION = '0.004';
+
+use warnings::register;
+
+use X3D::Environment;
+
 1;
 __END__
+
 package SbColor;
 1;
 package SbColorRGBA;
