@@ -1,6 +1,6 @@
 package X3D::Components::Core;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 #Abstract types
 use X3D::Components::Core::Node;
@@ -12,7 +12,7 @@ use X3D::Components::Core::SensorNode;
 use X3D::Components::Core::InfoNode;
 
 #Node reference
-use X3D::Namespace;
+use X3D::NodeTypes;
 
 use X3D::Components::Core::Nodes::MetadataDouble;
 use X3D::Components::Core::Nodes::MetadataFloat;
@@ -21,7 +21,7 @@ use X3D::Components::Core::Nodes::MetadataSet;
 use X3D::Components::Core::Nodes::MetadataString;
 use X3D::Components::Core::Nodes::WorldInfo;
 
-no X3D::Namespace;
+no X3D::NodeTypes;
 
 1;
 __END__
