@@ -78,75 +78,75 @@ use Weed 'TestNode : X3DBaseNode {
 	SFVec4d		[] fsfvec4d 	 0 0 0 0
 	SFVec4f		[] fsfvec4f 	 0 0 0 0
 	
-	MFBool		[in] inmfbool  	 []
-	MFColor		[in] inmfcolor 	 []
-	MFColorRGBA	[in] inmfcolorrgba []
-	MFDouble		[in] inmfdouble	 []
-	MFFloat		[in] inmffloat 	 []
-	MFImage		[in] inmfimage 	 []
-	MFInt32		[in] inmfint32 	 []
-	MFNode		[in] inmfnode  	 []
-	MFRotation	[in] inmfrotation  []
-	MFString		[in] inmfstring	 []
-	MFTime		[in] inmftime  	 []
-	MFVec2d		[in] inmfvec2d 	 []
-	MFVec2f		[in] inmfvec2f 	 []
-	MFVec3d		[in] inmfvec3d 	 []
-	MFVec3f		[in] inmfvec3f 	 []
-	MFVec4d		[in] inmfvec4d 	 []
-	MFVec4f		[in] inmfvec4f 	 []
-	SFBool		[in] insfbool  	 FALSE
-	SFColor		[in] insfcolor 	 0 0 0
-	SFColorRGBA [in] insfcolorrgba 0 0 0 0
-	SFDouble 	[in] insfdouble	 0
-	SFFloat		[in] insffloat 	 0
-	SFImage		[in] insfimage 	 0 0 0
-	SFInt32		[in] insfint32 	 0
-	SFNode		[in] insfnode  	 NULL
-	SFRotation	[in] insfrotation  0 0 1 0
-	SFString 	[in] insfstring	 ""
-	SFTime		[in] insftime  	 0
-	SFVec2d		[in] insfvec2d 	 0 0
-	SFVec2f		[in] insfvec2f 	 0 0
-	SFVec3d		[in] insfvec3d 	 0 0 0
-	SFVec3f		[in] insfvec3f 	 0 0 0
-	SFVec4d		[in] insfvec4d 	 0 0 0 0
-	SFVec4f		[in] insfvec4f 	 0 0 0 0
+	MFBool		[in] inmfbool  	 
+	MFColor		[in] inmfcolor 	 
+	MFColorRGBA	[in] inmfcolorrgba 
+	MFDouble		[in] inmfdouble	 
+	MFFloat		[in] inmffloat 	 
+	MFImage		[in] inmfimage 	 
+	MFInt32		[in] inmfint32 	 
+	MFNode		[in] inmfnode  	 
+	MFRotation	[in] inmfrotation  
+	MFString		[in] inmfstring	 
+	MFTime		[in] inmftime  	 
+	MFVec2d		[in] inmfvec2d 	 
+	MFVec2f		[in] inmfvec2f 	 
+	MFVec3d		[in] inmfvec3d 	 
+	MFVec3f		[in] inmfvec3f 	 
+	MFVec4d		[in] inmfvec4d 	 
+	MFVec4f		[in] inmfvec4f 	 
+	SFBool		[in] insfbool  	 
+	SFColor		[in] insfcolor 	 
+	SFColorRGBA [in] insfcolorrgba 
+	SFDouble 	[in] insfdouble	 
+	SFFloat		[in] insffloat 	 
+	SFImage		[in] insfimage 	 
+	SFInt32		[in] insfint32 	 
+	SFNode		[in] insfnode  	 
+	SFRotation	[in] insfrotation  
+	SFString 	[in] insfstring	 
+	SFTime		[in] insftime  	 
+	SFVec2d		[in] insfvec2d 	 
+	SFVec2f		[in] insfvec2f 	 
+	SFVec3d		[in] insfvec3d 	 
+	SFVec3f		[in] insfvec3f 	 
+	SFVec4d		[in] insfvec4d 	 
+	SFVec4f		[in] insfvec4f 	 
 	
-	MFBool		[out] outmfbool	   []
-	MFColor		[out] outmfcolor	   []
-	MFColorRGBA	[out] outmfcolorrgba []
-	MFDouble		[out] outmfdouble    []
-	MFFloat		[out] outmffloat	   []
-	MFImage		[out] outmfimage	   []
-	MFInt32		[out] outmfint32	   []
-	MFNode		[out] outmfnode	   []
-	MFRotation	[out] outmfrotation  []
-	MFString		[out] outmfstring    []
-	MFTime		[out] outmftime	   []
-	MFVec2d		[out] outmfvec2d	   []
-	MFVec2f		[out] outmfvec2f	   []
-	MFVec3d		[out] outmfvec3d	   []
-	MFVec3f		[out] outmfvec3f	   []
-	MFVec4d		[out] outmfvec4d	   []
-	MFVec4f		[out] outmfvec4f	   []
-	SFBool		[out] outsfbool	   FALSE
-	SFColor		[out] outsfcolor	   0 0 0
-	SFColorRGBA [out] outsfcolorrgba 0 0 0 0
-	SFDouble 	[out] outsfdouble    0
-	SFFloat		[out] outsffloat	   0
-	SFImage		[out] outsfimage	   0 0 0
-	SFInt32		[out] outsfint32	   0
-	SFNode		[out] outsfnode	   NULL
-	SFRotation	[out] outsfrotation  0 0 1 0
-	SFString 	[out] outsfstring    ""
-	SFTime		[out] outsftime	   0
-	SFVec2d		[out] outsfvec2d	   0 0
-	SFVec2f		[out] outsfvec2f	   0 0
-	SFVec3d		[out] outsfvec3d	   0 0 0
-	SFVec3f		[out] outsfvec3f	   0 0 0
-	SFVec4d		[out] outsfvec4d	   0 0 0 0
-	SFVec4f		[out] outsfvec4f	   0 0 0 0
+	MFBool		[out] outmfbool	   
+	MFColor		[out] outmfcolor	   
+	MFColorRGBA	[out] outmfcolorrgba 
+	MFDouble		[out] outmfdouble    
+	MFFloat		[out] outmffloat	   
+	MFImage		[out] outmfimage	   
+	MFInt32		[out] outmfint32	   
+	MFNode		[out] outmfnode	   
+	MFRotation	[out] outmfrotation  
+	MFString		[out] outmfstring    
+	MFTime		[out] outmftime	   
+	MFVec2d		[out] outmfvec2d	   
+	MFVec2f		[out] outmfvec2f	   
+	MFVec3d		[out] outmfvec3d	   
+	MFVec3f		[out] outmfvec3f	   
+	MFVec4d		[out] outmfvec4d	   
+	MFVec4f		[out] outmfvec4f	   
+	SFBool		[out] outsfbool	   
+	SFColor		[out] outsfcolor	   
+	SFColorRGBA [out] outsfcolorrgba 
+	SFDouble 	[out] outsfdouble    
+	SFFloat		[out] outsffloat	   
+	SFImage		[out] outsfimage	   
+	SFInt32		[out] outsfint32	   
+	SFNode		[out] outsfnode	   
+	SFRotation	[out] outsfrotation  
+	SFString 	[out] outsfstring    
+	SFTime		[out] outsftime	   
+	SFVec2d		[out] outsfvec2d	   
+	SFVec2f		[out] outsfvec2f	   
+	SFVec3d		[out] outsfvec3d	   
+	SFVec3f		[out] outsfvec3f	   
+	SFVec4d		[out] outsfvec4d	   
+	SFVec4f		[out] outsfvec4f	   
 	
 	MFBool		[in,out] want	      []
 	MFString		[in,out] say	      []
@@ -154,16 +154,22 @@ use Weed 'TestNode : X3DBaseNode {
 	SFFloat		[in,out] parseFloat  0
 	SFInt32		[in,out] parseInt    0
 	
+#	comment
+
 	SFString 	[in,out] belst      ""
 	SFString 	[in,out] be::lst    ""
-	SFString 	[in,out] 3be::lst   ""
-	SFString 	[in,out] isa         ""
+#	SFString 	[in,out] 3be::lst   ""
+	SFVec2d  	[in,out] isa         1 2
 	
 	MFDouble		[in,out] doubles     [1.2, 3.4, 5.6]
 	MFDouble		[in,out] doubles2    []
 
 	SFNode		[in,out] sfnode2	   NULL
-	MFNode		[in,out] mfnode2	   []
+	MFNode		[in,out] mfnode2	   []	
+	
+	SFVec4d		[in,out] sfvec4d2	   0 0 0 0
+	MFVec4d		[in,out] mfvec4d2	   []
+
 
 #	MFNode		[in,out] mfnull	   [ NULL ]
 }
