@@ -1,4 +1,4 @@
-package TestType;
+package TestTypeBase;
 
 BEGIN {
 	$| = 1;
@@ -9,7 +9,7 @@ BEGIN {
 
 use Weed 'TestType {}';
 
-sub new { shift->_new }
+sub new { shift->X3DUniversal::new }
 
 1;
 __END__
